@@ -1,5 +1,5 @@
 /*
-    $Id: vcd_xml_master.c,v 1.36 2005/05/08 03:48:55 rocky Exp $
+    $Id: vcd_xml_master.c,v 1.38 2005/06/09 00:53:23 rocky Exp $
 
     Copyright (C) 2001, 2005 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -38,20 +38,20 @@
 #endif
 #include <stdio.h>
 
-static const char _rcsid[] = "$Id: vcd_xml_master.c,v 1.36 2005/05/08 03:48:55 rocky Exp $";
+static const char _rcsid[] = "$Id: vcd_xml_master.c,v 1.38 2005/06/09 00:53:23 rocky Exp $";
 
 /* important date to celebrate (for me at least =)
    -- until user customization is implemented... */
 static const time_t _vcd_time = 269222400L;
 
-static VcdDataSource *
+static VcdDataSource_t *
 mk_dsource (const char prefix[], const char pathname[])
 {
   vcd_assert (pathname != 0);
 
   if (prefix) 
     {
-      VcdDataSource *retval = 0;
+      VcdDataSource_t *retval = 0;
       char *tmp = calloc(1, strlen (prefix) + strlen (pathname) + 1);
       strcpy (tmp, prefix);
       strcat (tmp, pathname);
@@ -64,7 +64,7 @@ mk_dsource (const char prefix[], const char pathname[])
 }
 
 bool 
-vcd_xml_master (const vcdxml_t *p_vcdxml, VcdImageSink *image_sink, 
+vcd_xml_master (const vcdxml_t *p_vcdxml, VcdImageSink_t *p_image_sink, 
 		time_t *create_time)
 {
   VcdObj_t *_vcd;
@@ -220,7 +220,7 @@ vcd_xml_master (const vcdxml_t *p_vcdxml, VcdImageSink *image_sink,
       
       if (dentry->file_src) 
 	{
-	  VcdDataSource *_source = mk_dsource (p_vcdxml->file_prefix, 
+	  VcdDataSource_t *_source = mk_dsource (p_vcdxml->file_prefix, 
 					       dentry->file_src);
 	  
 	  vcd_assert (_source != NULL);
@@ -236,7 +236,7 @@ vcd_xml_master (const vcdxml_t *p_vcdxml, VcdImageSink *image_sink,
   _CDIO_LIST_FOREACH (node, p_vcdxml->segment_list)
     {
       struct segment_t *p_segment = _cdio_list_node_data (node);
-      VcdDataSource *_source = mk_dsource (p_vcdxml->file_prefix, 
+      VcdDataSource_t *_source = mk_dsource (p_vcdxml->file_prefix, 
 					   p_segment->src);
       CdioListNode_t *p_node2;
       VcdMpegSource_t *_mpeg_src;
@@ -270,7 +270,7 @@ vcd_xml_master (const vcdxml_t *p_vcdxml, VcdImageSink *image_sink,
   _CDIO_LIST_FOREACH (node, p_vcdxml->sequence_list)
     {
       struct sequence_t *sequence = _cdio_list_node_data (node);
-      VcdDataSource *data_source;
+      VcdDataSource_t *data_source;
       CdioListNode_t *node2;
       VcdMpegSource_t *_mpeg_src;
 
@@ -315,7 +315,7 @@ vcd_xml_master (const vcdxml_t *p_vcdxml, VcdImageSink *image_sink,
 
     sectors = vcd_obj_begin_output (_vcd);
 
-    vcd_obj_write_image (_vcd, image_sink, vcd_xml_show_progress 
+    vcd_obj_write_image (_vcd, p_image_sink, vcd_xml_show_progress 
 			 ? vcd_xml_write_progress_cb : NULL, 
 			 NULL, &_vcd_time);
 
