@@ -1,5 +1,5 @@
 /*
-    $Id: vcd.h,v 1.3 2005/05/08 03:48:55 rocky Exp $
+    $Id: vcd.h,v 1.5 2005/06/09 00:53:23 rocky Exp $
 
     Copyright (C) 2000, 2005 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -80,7 +80,7 @@ extern "C" {
       byte blocksize */
   int
   vcd_obj_add_file (VcdObj_t *p_vcdobj, const char iso_pathname[],
-                    VcdDataSource *p_file, bool raw_flag);
+                    VcdDataSource_t *p_file, bool raw_flag);
   
   int
   vcd_obj_add_dir (VcdObj_t *p_vcdobj, const char iso_pathname[]);
@@ -148,7 +148,7 @@ extern "C" {
   /** writes the actual bin image file; a return value != 0 means the
       action was aborted by user or some other error has occured... */
   int
-  vcd_obj_write_image (VcdObj_t *p_vcdobj, VcdImageSink *p_image_sink,
+  vcd_obj_write_image (VcdObj_t *p_vcdobj, VcdImageSink_t *p_image_sink,
                        progress_callback_t callback, void *p_user_data,
                        const time_t *p_create_time);
   
